Command Line Interfaces
=======================

Included in the freewili python module are two command line interfaces to interact with a Free-Wili device without writing any code.


fwi-serial command line interface
---------------------------------
Interact with a Free-Wili device over serial.

.. command-output:: fwi-serial --help



fwi-convert command line interface
----------------------------------

Used to convert image files to Free-Wili (fwi) files. This is useful for preparing images to be displayed on a Free-Wili device.

.. command-output:: fwi-convert --help
